#####################
### Preliminaries ###
#####################
# Loading packages
require(ggplot2)

############
### Data ###
############
# Loading mtcars dataset
data(mtcars)

###################
### Correlation ###
###################
# Plotting fuel consumption against weight
ggplot(mtcars) + # ggplot with the desired data
  geom_point(aes(x=wt,y=mpg)) + 
  labs(x='Weight',y='Fuel consumption (in miles per gallon)') # Labels

# Plotting fuel consumption against horsepower
ggplot(mtcars) + # ggplot with the desired data
  geom_point(aes(x=hp,y=mpg)) + # Specifying scatterplot
  labs(x='Horsepower',y='Fuel consumption (in miles per gallon)') # Labels

# Plotting fuel consumption against number of cylinders
ggplot(mtcars) + # ggplot with the desired data
  geom_point(aes(x=cyl,y=mpg)) + # Specifying scatterplot
  labs(x='Number of cylinders',y='Fuel consumption (in miles per gallon)') # Labels

# Plotting fuel consumption against quarter mile time
ggplot(mtcars) + # ggplot with the desired data
  geom_point(aes(x=qsec,y=mpg)) + # Specifying scatterplot
  labs(x='Quarter Mile Time',y='Fuel consumption (in miles per gallon)') # Labels

# Calculating the correlation coefficient between fuel consumption
# weight, horsepower, number of cylinders and quarter mile time
cor(mtcars[,c('mpg','wt','hp','cyl','qsec')])

#########################
### Linear Regression ###
#########################
# Plotting fuel consumption against weight
ggplot(mtcars) + # ggplot with the desired data
  geom_point(aes(x=wt,y=mpg)) + 
  labs(x='Weight',y='Fuel consumption\n(in miles per gallon)')

# Model formula mpg ~ 1 + wt (mpg = a + b * weight)
formula <- mpg ~ 1 + wt

# Fitting the linear model
mod <- lm(formula, data=mtcars) 

# Plotting fuel consumption against weight
ggplot(mtcars, aes(x=wt,y=mpg)) + # ggplot with the desired data
  geom_point() + 
  geom_line(aes(x=wt,y=fitted(mod)),colour='red',) +
  labs(x='Weight',y='Fuel consumption\n(in miles per gallon)')

# Summarising the fitted model 
summary(mod)

# Calculating confidence intervals of model coefficients 
confint(mod, # Linear Model fit
        level = 0.95) # Significance level

# Predicting for a weight of 3.5
predict(mod, # Fitted model
newdata = data.frame(mpg=NA, wt=3.5)) # Data that we want to predict for

###########################
### Multiple Regression ###
###########################
# Plotting fuel consumption against weight
ggplot(mtcars) + # ggplot with the desired data
geom_point(aes(x=wt,y=mpg)) + 
labs(x='Weight',y='Fuel consumption\n(in miles per gallon)')

# Plotting fuel consumption against weight
ggplot(mtcars) + # ggplot with the desired data
geom_point(aes(x=hp,y=mpg)) + 
labs(x='Horsepower',y='Fuel consumption\n(in miles per gallon)')

# Model formula mpg ~ 1 + wt (mpg = a + b * weight)
formula <- mpg ~ 1 + wt + hp

# Fitting the linear model
mod <- lm(formula, data=mtcars) 

# Summarising the fitted model 
summary(mod)

# Calculating confidence intervals of model coefficients 
confint(mod, # Linear Model fit
level = 0.95) # Significance level

# Predicting for a weight of 3.5 and horsepower of 200
predict(mod, # Fitted model
newdata = data.frame(mpg=NA, wt=3.5, hp=200)) # Data that we want to predict for

###########################
### Choosing your model ###
###########################
# Fitting model with weight 
formula1 <- mpg ~ 1 + wt 
mod1 <- lm(formula1, data = mtcars)

# Fitting model with horsepower 
formula2 <- mpg ~ 1 + hp
mod2 <- lm(formula2, data = mtcars)

# Fitting model with both weight and horsepower 
formula3 <- mpg ~ 1 + wt + hp
mod3 <- lm(formula2, data = mtcars)

# Extracting adjusted R2 from model 1
summary(mod1)$adj.r.squared

# Extracting adjusted R2 from model 2
summary(mod2)$adj.r.squared

# Extracting adjusted R2 from model 3
summary(mod3)$adj.r.squared




